@@ -4,6 +4,8 @@ GET a recipe, PUT a recipe, GET the tiddlers
 produced by a recipe.
 """
 
+from httpexceptor import HTTP400, HTTP409, HTTP415, HTTP404
+
 from tiddlyweb.filters import FilterError
 from tiddlyweb.model.collections import Tiddlers
 from tiddlyweb.model.bag import Bag
@@ -13,7 +15,6 @@ from tiddlyweb.store import (NoRecipeError, NoBagError,
         StoreMethodNotImplemented)
 from tiddlyweb.serializer import (Serializer, NoSerializationError,
         RecipeFormatError)
-from tiddlyweb.web.http import HTTP400, HTTP409, HTTP415, HTTP404
 from tiddlyweb.web.sendentity import send_entity
 from tiddlyweb.web.sendtiddlers import send_tiddlers
 from tiddlyweb.web.listentities import list_entities
@@ -90,10 +91,10 @@ def get_tiddlers(environ, start_response):
     except FilterError, exc:
         raise HTTP400('malformed filter: %s' % exc)
 
-    if filters:
-        tiddlers = Tiddlers(title=title)
-    else:
-        tiddlers = Tiddlers(title=title, store=store)
+    tiddlers = Tiddlers(title=title)
+    if not filters:
+        tiddlers.store = store
+    tiddlers.recipe = recipe.name
 
     for tiddler in candidate_tiddlers:
         tiddler.recipe = recipe.name
@@ -109,11 +110,7 @@ def list_recipes(environ, start_response):
     """
     Get a list of all recipes the current user can read.
     """
-    store = environ['tiddlyweb.store']
-    serialize_type, mime_type = web.get_serialize_type(environ)
-    serializer = Serializer(serialize_type, environ)
-    return list_entities(environ, start_response, mime_type,
-            store.list_recipes, serializer.list_recipes)
+    return list_entities(environ, start_response, 'list_recipes')
 
 
 def put(environ, start_response):
